Rot2

Struct Rot2 

#[repr(C)]
pub struct Rot2 { pub re: f32, pub im: f32, }
A 2D rotation represented as a unit complex number (f32 precision).

The rotation is stored as re + im * i where re = cos(angle) and im = sin(angle).

Fields

re: f32

Real part (cosine of the angle).

im: f32

Imaginary part (sine of the angle).

Implementations

Source

impl Rot2

pub const IDENTITY: Rot2

The identity rotation (no rotation).

pub const fn from_cos_sin_unchecked(re: f32, im: f32) -> Rot2

Creates a new unit complex from cosine and sine values.

The caller must ensure that re*re + im*im = 1.

pub fn from_matrix_unchecked(mat: Mat2) -> Rot2

Creates a rotation from a rotation matrix (without normalization).

pub fn identity() -> Rot2

Creates the identity rotation.

pub fn new(angle: f32) -> Rot2

Creates a rotation from an angle in radians.

pub fn from_angle(angle: f32) -> Rot2

Creates a rotation from an angle in radians.

pub fn angle(&self) -> f32

Returns the rotation angle in radians.

pub fn cos(&self) -> f32

Returns the cosine of the rotation angle (the real part).

pub fn sin(&self) -> f32

Returns the sine of the rotation angle (the imaginary part).

pub fn inverse(self) -> Rot2

Returns the inverse rotation.

pub fn length(&self) -> f32

Computes the length (magnitude) of self.

For a valid unit rotation, this should always be 1.0.

pub fn length_squared(&self) -> f32

Computes the squared length of self.

This is faster than length() as it avoids a square root. For a valid unit rotation, this should always be 1.0.

pub fn length_recip(&self) -> f32

Computes 1.0 / length().

pub fn normalize(&self) -> Rot2

Returns self normalized to length 1.0.

For valid unit rotations this should be a no-op.

pub fn is_finite(&self) -> bool

Returns true if, and only if, all elements are finite.

pub fn is_nan(&self) -> bool

Returns true if any element is NaN.

pub fn is_normalized(&self) -> bool

Returns whether self is of length 1.0 or not.

Uses a precision threshold of approximately 1e-4.

pub fn transform_vector(&self, v: Vec2) -> Vec2

Rotates a 2D vector by this rotation.

pub fn inverse_transform_vector(&self, v: Vec2) -> Vec2

Transforms a 2D vector by the inverse of this rotation.

pub fn to_mat(&self) -> Mat2

Returns the rotation matrix equivalent to this rotation.

pub fn from_mat(mat: Mat2) -> Rot2

Creates a rotation from a 2x2 rotation matrix.

The matrix should be a valid rotation matrix (orthogonal with determinant 1).

pub fn from_mat_unchecked(mat: Mat2) -> Rot2

Creates a rotation from a 2x2 matrix without normalization.

Alias for from_matrix_unchecked.

pub fn from_rotation_arc(from: Vec2, to: Vec2) -> Rot2

Gets the minimal rotation for transforming from to to.

Both vectors must be normalized. The rotation is in the plane spanned by the two vectors.

pub fn slerp(&self, other: &Rot2, t: f32) -> Rot2

Spherical linear interpolation between two rotations.

pub fn powf(&self, n: f32) -> Rot2

Raises this rotation to a power.

For example, powf(2.0) will return a rotation with double the angle.

pub fn rotate_towards(&self, rhs: &Rot2, max_angle: f32) -> Rot2

Rotates self towards rhs up to max_angle (in radians).

When max_angle is 0.0, the result will be equal to self. When max_angle is equal to self.angle_between(rhs), the result will be equal to rhs. If max_angle is negative, rotates towards the exact opposite of rhs. Will not go past the target.

pub fn angle_between(&self, rhs: &Rot2) -> f32

Returns the angle (in radians) between self and rhs.

pub fn dot(&self, rhs: Rot2) -> f32

Computes the dot product of self and rhs.

The dot product is equal to the cosine of the angle between two rotations.

pub fn lerp(&self, rhs: Rot2, s: f32) -> Rot2

Performs a linear interpolation between self and rhs based on the value s.

When s is 0.0, the result will be equal to self. When s is 1.0, the result will be equal to rhs. For rotations, slerp is usually preferred over lerp.

pub fn normalize_mut(&mut self)

Normalizes self in place.

Does nothing if self is already normalized or zero length.