Pose

Type Alias Pose 

pub type Pose = Pose3;
The transformation matrix type (pose = rotation + translation).

Aliased Type

#[repr(C)]
pub struct Pose { pub rotation: Quat, pub translation: Vec3, pub padding: u32, }

Fields

rotation: Quat

The rotational part of the pose.

translation: Vec3

The translational part of the pose.

padding: u32

Explicit padding for compatibility with bytemuck and targets like spirv.

Can have any value as it is never read from or written to.