pub struct Pose2 {
pub rotation: Rot2,
pub translation: Vec2,
}Expand description
A 2D pose (rotation + translation), representing a rigid body transformation (f32 precision).
Fields
rotation: Rot2The rotational part of the pose.
translation: Vec2The translational part of the pose.
Implementations
Sourceimpl Pose2
impl Pose2
Sourcepub fn from_translation(translation: Vec2) -> Pose2
pub fn from_translation(translation: Vec2) -> Pose2
Creates a pose from a translation vector.
Sourcepub fn translation(x: f32, y: f32) -> Pose2
pub fn translation(x: f32, y: f32) -> Pose2
Creates a pose from translation components.
Sourcepub fn from_rotation(rotation: Rot2) -> Pose2
pub fn from_rotation(rotation: Rot2) -> Pose2
Creates a pose from a rotation.
Sourcepub fn rotation(angle: f32) -> Pose2
pub fn rotation(angle: f32) -> Pose2
Creates a pose that is a pure rotation with the given angle (in radians).
Sourcepub fn from_parts(translation: Vec2, rotation: Rot2) -> Pose2
pub fn from_parts(translation: Vec2, rotation: Rot2) -> Pose2
Creates a pose from translation and rotation parts.
Sourcepub fn prepend_translation(self, translation: Vec2) -> Pose2
pub fn prepend_translation(self, translation: Vec2) -> Pose2
Prepends a translation to this pose (applies translation in local frame).
Sourcepub fn append_translation(self, translation: Vec2) -> Pose2
pub fn append_translation(self, translation: Vec2) -> Pose2
Appends a translation to this pose (applies translation in world frame).
Sourcepub fn transform_point(&self, p: Vec2) -> Vec2
pub fn transform_point(&self, p: Vec2) -> Vec2
Transforms a 2D point by this pose.
This applies both the rotation and translation.
Sourcepub fn transform_vector(&self, v: Vec2) -> Vec2
pub fn transform_vector(&self, v: Vec2) -> Vec2
Transforms a 2D vector by this pose.
This applies only the rotation (ignores translation).
Sourcepub fn inverse_transform_point(&self, p: Vec2) -> Vec2
pub fn inverse_transform_point(&self, p: Vec2) -> Vec2
Transforms a point by the inverse of this pose.
Sourcepub fn inverse_transform_vector(&self, v: Vec2) -> Vec2
pub fn inverse_transform_vector(&self, v: Vec2) -> Vec2
Transforms a vector by the inverse of this pose.