pub type Pose = Pose3;Expand description
The transformation matrix type (pose = rotation + translation).
Aliased Type
#[repr(C)]pub struct Pose {
pub rotation: Quat,
pub translation: Vec3,
pub padding: u32,
}Fields
rotation: QuatThe rotational part of the pose.
translation: Vec3The translational part of the pose.
padding: u32Explicit padding for compatibility with bytemuck and targets like spirv.
Can have any value as it is never read from or written to.