pub type SdpMatrix = SdpMatrix3<f32>;Expand description
A 3D symmetric-definite-positive matrix.
Aliased Type
pub struct SdpMatrix {
pub m11: f32,
pub m12: f32,
pub m13: f32,
pub m22: f32,
pub m23: f32,
pub m33: f32,
}Fields
m11: f32The component at the first row and first column of this matrix.
m12: f32The component at the first row and second column of this matrix.
m13: f32The component at the first row and third column of this matrix.
m22: f32The component at the second row and second column of this matrix.
m23: f32The component at the second row and third column of this matrix.
m33: f32The component at the third row and third column of this matrix.